==> jc-1.4.0.tar.gz: soot/jimple/spark/pag/PAGDumper__24ObjectNumberer.h <==
// class soot.jimple.spark.pag.PAGDumper$ObjectNumberer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fcf0022947dc8363 soot_jimple_spark_pag_PAGDumper__24ObjectNumberer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer_H_
#define _JC_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_jimple_spark_pag_PAGDumper$object;
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_refs	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_nonrefs	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$refs	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$refs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$nonrefs	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object;

typedef const struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vmethods	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtable	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtable;
typedef const struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtype	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$method$_init$2eecc63b09fae430(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_java_lang_Object$object *, jint);

// Virtual methods
extern struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object *_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$method$findOrAdd$d5465ef541428bee(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$method_info$findOrAdd$d5465ef541428bee;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vmethods {
	struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object	*(*findOrAdd$d5465ef541428bee)(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vmethods	soot_jimple_spark_pag_PAGDumper__24ObjectNumberer;
};

// Vtype
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_refs {
	struct _jc_java_lang_Object$object	*o;
	struct _jc_java_util_HashMap$object	*children;
	struct _jc_soot_jimple_spark_pag_PAGDumper$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$refs {
    _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_refs	soot_jimple_spark_pag_PAGDumper__24ObjectNumberer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_nonrefs {
	jint	num;
	jint	nextChildNum;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_nonrefs	soot_jimple_spark_pag_PAGDumper__24ObjectNumberer;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object {
	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtype	*vtype;
	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtype _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_PAGDumper__24ObjectNumberer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$class_object;

#endif	/* _JC_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/pag/PAGDumper__24ObjectNumberer.h <==
// class soot.jimple.spark.pag.PAGDumper$ObjectNumberer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fcf0022947dc8363 soot_jimple_spark_pag_PAGDumper__24ObjectNumberer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer_H_
#define _JC_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_jimple_spark_pag_PAGDumper$object;
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_refs	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_nonrefs	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$refs	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$refs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$nonrefs	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object;

typedef const struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vmethods	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtable	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtable;
typedef const struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtype	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$method$_init$2eecc63b09fae430(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_java_lang_Object$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object *_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$method$findOrAdd$d5465ef541428bee(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$method_info$findOrAdd$d5465ef541428bee;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vmethods {
	struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object	*(*findOrAdd$d5465ef541428bee)(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vmethods	soot_jimple_spark_pag_PAGDumper__24ObjectNumberer;
};

// Vtype
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_refs {
	struct _jc_java_lang_Object$object	*o;
	struct _jc_java_util_HashMap$object	*children;
	struct _jc_soot_jimple_spark_pag_PAGDumper$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$refs {
    _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_refs	soot_jimple_spark_pag_PAGDumper__24ObjectNumberer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_nonrefs {
	jint	num;
	jint	nextChildNum;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$sub_nonrefs	soot_jimple_spark_pag_PAGDumper__24ObjectNumberer;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object {
	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtype	*vtype;
	_jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$vtype _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_PAGDumper__24ObjectNumberer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$class_object;

#endif	/* _JC_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer_H_ */
